use_pkgbuild_rmd: Create R Markdown Template for Building Package

View source: R/build_rmd.R

use_pkgbuild_rmdR Documentation

Create R Markdown Template for Building Package

Description

Create R Markdown file which contains functions to use in R package development process. use_pkgbuild_rmd() will:

  • Create dev/build.Rmd relative to the package root

  • Add ^dev$ to .Rbuildignore

  • Open build.Rmd for editing

Usage

use_pkgbuild_rmd(
  overwrite = FALSE,
  open = rlang::is_interactive(),
  remote = FALSE,
  url = NULL
)

Arguments

overwrite

If dev/build.Rmd already exist, TRUE to overwrite an existing file, FALSE to throw an error.

open

Whether to open the file for interactive editing.

remote

Remote template options, choose one of:

  • FALSE: (default) To use a local template stored in pkgtemp.

  • TRUE: To download a default template file from in GitHub that you have already setup by set_github_template_url().

url

If not NULL, provide a GitHub URL to download a template file from.

Value

A path to newly created file.

See Also

  • set_github_template_url(): for setting GitHub URL to download your own template file

Examples

## Not run: 
# Write `dev/build.Rmd` and open for edit
use_pkgbuild_rmd()

## End(Not run)

Lightbridge-KS/pkgtemp documentation built on May 10, 2022, 7:33 p.m.